disp(' ');
disp(' fds_force_main.m   ver 1.3   August 5, 2014');
disp(' ');
disp(' by Tom Irvine');
disp(' ');
disp(' Fatigue damage spectrum for applied force via: ');
disp(' ASTM E 1049-85 (2005) Rainflow Counting Method ');
disp(' ');
%
clear t;
clear y;
clear y_resp;
clear Q
clear damp;
clear bex;
clear D;
clear fn;
clear damage;
clear pos;
clear neg;
%
close all;
fig_num=1;
%
disp(' Select units ');
disp(' 1=lbf,G,in/sec,in');
disp(' 2=N,G,m/sec,mm');
disp(' 3=N,m/sec^2,m/sec,m');
%
iu=input(' ');
%
disp('');
if(iu==1)
    mass=input(' Enter mass (lbm) ');
    mass_orig=mass;
    mass=mass/386;
else
    mass=input(' Enter mass (kg) ');
    mass_orig=mass;    
end
%
%
disp('');
idamp=input(' Enter damping format:  1= damping ratio   2= Q  ');
%
disp(' ')
if(idamp==1)
   damp=input(' Enter damping ratio (typically 0.05) ');
   Q=1./(2.*damp);
else
   Q=input(' Enter the amplification factor (typically Q=10) ');
   damp=1./(2.*Q);
end
%
disp(' ');
disp(' Enter fatigue exponent ');
bex=input(' ');
%
%
disp(' The input file must be a force time history with two columns: ')
if(iu==1)
    disp('  Time(sec) & Force(lbf) ');
else
    disp('  Time(sec) & Force(N) ');    
end    
disp(' ');
%
disp(' ');
[t,force,dt,sr,tmx,tmi,n,ncontinue]=enter_time_history();
%
figure(fig_num);
fig_num=fig_num+1;
plot(t,force);
grid on;
xlabel('Time (sec)');
if(iu==1)
    ylabel('Force (lbf)');    
else
    ylabel('Force (N)');
end
%
out1=sprintf(' total input points =%d ',n);
disp(out1);
%
disp(' ');
disp(' Select fatigue metric ');
disp('  1=acceleration ');
disp('  2=velocity ');
disp('  3=displacement ');
disp('  4=transmitted force ');
im=input(' ');
%
dchoice=1.;
%
fn(1)=input(' Enter the starting frequency (Hz)  ');
fend =input(' Enter the   ending frequency (Hz)  ');
fmax=fend;
%
if fn(1)>sr/30.
    fn(1)=sr/30.;
end
fmin=fn(1);
%
j=1;
while(1)
    if (fn(j) > sr/8. || fn(j)>fend)
        break
    end
    fn(j+1)=fn(1)*(2. ^ (j*(1./12.)));
    j=j+1;
end
%
fn=fn';
%
n=length(fn);
%
damage=zeros(n,1);
%
pos=zeros(n,1);
neg=zeros(n,1);
%
ff=force/mass;
%
progressbar;
%
ndof=1;
%
for i=1:n
%
    progressbar(i/n);
%
     omegan=2*pi*fn(i);
     
     if(im<=3)
        [a1,a2,df1,df2,df3,vf1,vf2,vf3,af1,af2,af3]=...
                   ramp_invariant_filter_coefficients(ndof,omegan,damp,dt);
     else
        [a1,a2,b1,b2,b3,rd_a1,rd_a2,rd_b1,rd_b2,rd_b3]=...
                   srs_coefficients(fn(i),damp,dt);         
     end
%
     if(im==1) % acceleration
%
        a_forward=[   af1,  af2, af3 ];
        a_back   =[     1, -a1, -a2 ]; 
        y_resp=filter(a_forward,a_back,ff);
%        
        if(iu==1)
            y_resp=y_resp/386;
        end
        if(iu==2)
            y_resp=y_resp/9.81;
        end        
     end
%
     if(im==2) % velocity
        v_forward=[   vf1,  vf2, vf3 ];
        v_back   =[     1, -a1, -a2 ];
        y_resp=filter(v_forward,v_back,ff);      
     end
%
    if(im==3) % displacement
        d_forward=[   df1,  df2, df3 ];
        d_back   =[     1, -a1, -a2 ];
        y_resp=filter(d_forward,d_back,ff);        
        if(iu>=2)
            y_resp=y_resp*1000;
        end
    end
%
    if(im==4) % transmitted force
        back   =[     1, -a1, -a2 ];
        aa_forward=[ b1,  b2,  b3 ];
%    
        y_resp=filter(aa_forward,back,force);        
    end    
%
    [L,C,AverageAmp,MaxAmp,AverageMean,MinValley,MaxPeak,D]=rainflow_fds_mex(y_resp,dchoice,bex);
%
    damage(i)=D;
    pos(i)=max(y_resp);
    neg(i)=abs(min(y_resp));
end
%
pause(0.3);
progressbar(1);
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
fn=fix_size(fn);
pos=fix_size(pos);
neg=fix_size(neg);
damage=fix_size(damage);
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%
disp(' ');
%
b=sprintf('%g',bex);
b=strrep(b, '.', 'p');
%
if(im==1)  
    varname1=sprintf('accel_FDS_Q%g_b%s',Q,b);   
    if(iu<=2) 
            out1 = sprintf(' Acceleration FDS mass=%g lbm Q=%g b=%g',mass_orig,Q,bex);        
            ylab=sprintf('Damage Index (G^{ %g })',bex);             
    else    
            out1 = sprintf(' Acceleration FDS mass=%g kg Q=%g b=%g',mass_orig,Q,bex);       
            ylab=sprintf('Damage Index ((m/sec^2)^{ %g })',bex);         
    end     
end
if(im==2)
    varname1=sprintf('vel_FDS_Q%g_b%s',Q,b);
    
    if(iu==1) 
            out1 = sprintf(' Velocity FDS mass=%g lbm Q=%g b=%g',mass_orig,Q,bex);        
            ylab=sprintf('Damage Index (ips^{ %g })',bex);             
    else    
            out1 = sprintf(' Velocity FDS mass=%g kg Q=%g b=%g',mass_orig,Q,bex);       
            ylab=sprintf('Damage Index ((m/sec)^{ %g })',bex);         
    end     
end
if(im==3)
    varname1=sprintf('disp_FDS_Q%g_b%s',Q,b);
    if(iu==1)  
            out1 = sprintf(' Displacement FDS mass=%g lbm Q=%g b=%g',mass_orig,Q,bex); 
            ylab=sprintf('Damage Index (in^{ %g })',bex);
    else
            out1 = sprintf(' Displacement FDS mass=%g kg Q=%g b=%g',mass_orig,Q,bex); 
            ylab=sprintf('Damage Index (mm^{ %g })',bex);            
   end     
end
if(im==4)
    varname1=sprintf('trans_force_FDS_Q%g_b%s',Q,b);
    out1 = sprintf(' Transmitted Force Fatigue Damage Spectrum Q=%g b=%g',Q,bex);   
    if(iu==1) 
            ylab=sprintf('Damage Index (lbf^{ %g })',bex);             
    else         
            ylab=sprintf('Damage Index (N^{ %g })',bex);         
    end      
end
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   plots
%
figure(fig_num);
fig_num=fig_num+1;
%
    plot(fn,damage);
    xlabel('Natural Frequency (Hz)');
    grid on;
    set(gca,'MinorGridLineStyle',':','GridLineStyle',':','XScale','log','YScale','log');
    title(out1);
    xlim([fmin fmax])
    ylabel(ylab);
%
    if(round(fmin)==20 && round(fmax)==2000)
        set(gca,'xtick',[20 30 40 50 60 70 80 90 100 200 300 400 500 600 700 800 900 1000 2000])
        set(gca,'XTickLabel',{'20';'';'';'';'';'';'';'';'100';'';'';'';'';'';'';'';'';'1000';'2000';})
    end
    if(round(fmin)==10 && round(fmax)==2000)
        set(gca,'xtick',[10 20 30 40 50 60 70 80 90 100 200 300 400 500 600 700 800 900 1000 2000])
        set(gca,'XTickLabel',{'10';'';'';'';'';'';'';'';'';'100';'';'';'';'';'';'';'';'';'1000';'2000';})   
    end
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
out1=sprintf(' Output array: %s  -  fn(Hz) & Damage Index',varname1);
eval([varname1 ' = [fn damage];']);
disp(out1);
%
disp(' ');
disp(' The fatigue damage spectra is calculated from the amplitude (peak-valley)/2 ');
