disp(' ');
disp(' fds_main.m   ver 1.5   August 4, 2014');
disp(' ');
disp(' by Tom Irvine');
disp(' ');
disp(' Fatigue damage spectrum for base excitation via: ');
disp(' ASTM E 1049-85 (2005) Rainflow Counting Method ');
disp(' ');
%
clear t;
clear y;
clear y_resp;
clear Q
clear damp;
clear bex;
clear D;
clear fn;
clear damage;
clear pos;
clear neg;
%
close all;
fig_num=1;
%
disp(' The input file must be an acceleration time history ')
disp('  Time(sec) & Accel(G) ');
disp(' ');
%
[t,y,dt,sr,tmx,tmi,n,ncontinue]=enter_time_history();
%
figure(fig_num);
fig_num=fig_num+1;
plot(t,y);
grid on;
xlabel('Time (sec)');
ylabel('Accel (G)');
%
out1=sprintf(' total input points =%d ',n);
disp(out1);
%
disp(' ');
disp(' Select fatigue metric ');
disp('  1=acceleration ');
disp('  2=pseudo velocity ');
disp('  3=relative displacement ');
im=input(' ');
%
if(im==2)
    disp(' ');
    disp(' Select pseudo velocity metric ');
    disp('  1=inch/sec ');
    disp('  2=cm/sec ');
    iu=input(' ');
end
%
if(im==3)
    disp(' ');
    disp(' Select displacement metric ');
    disp('  1=inch ');
    disp('  2=mm ');
    iu=input(' ');
end
%
idamp=input(' Enter damping format:  1= damping ratio   2= Q  ');
%
disp(' ')
if(idamp==1)
   damp=input(' Enter damping ratio (typically 0.05) ');
   Q=1./(2.*damp);
else
   Q=input(' Enter the amplification factor (typically Q=10) ');
   damp=1./(2.*Q);
end
%
disp(' ');
disp(' Enter fatigue exponent ');
bex=input(' ');
%
dchoice=1.;
%
fn(1)=input(' Enter the starting frequency (Hz)  ');
fend =input(' Enter the   ending frequency (Hz)  ');
%
if fn(1)>sr/30.
    fn(1)=sr/30.;
end
%
j=1;
while(1)
    if (fn(j) > sr/8. || fn(j)>fend)
        break
    end
    fn(j+1)=fn(1)*(2. ^ (j*(1./12.)));
    j=j+1;
end
%
fn=fn';
%
n=length(fn);
%
damage=zeros(n,1);
%
pos=zeros(n,1);
neg=zeros(n,1);
%
progressbar;
%
for i=1:n
%
    progressbar(i/n);
%
     if(im==1)
        [y_resp]=arbit_function_accel(fn(i),damp,dt,y);   
     else
        [y_resp]=arbit_function_rd(fn(i),damp,dt,y);
     end
%
     if(im==2) % pseudo velocity (approx)
%         
         [y_resp]=differentiate_function(y_resp,dt);
%
         if(iu==1)
            y_resp=y_resp*386;
         else
            y_resp=y_resp*9.81*100;
         end
%
     end
%
    if(im==3) % relative displacement
        if(iu==1)
            y_resp=y_resp*386;
        else
            y_resp=y_resp*9.81*1000;
        end
    end
%
    
%
    [L,C,AverageAmp,MaxAmp,AverageMean,MinValley,MaxPeak,D]=rainflow_fds_mex(y_resp,dchoice,bex);
%
%%    out1=sprintf('  i=%d  D=%8.4g  ',i,D);
%%    disp(out1);
    damage(i)=D;
    pos(i)=max(y_resp);
    neg(i)=abs(min(y_resp));
end
%
pause(0.5);
progressbar(1);
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
fn=fix_size(fn);
pos=fix_size(pos);
neg=fix_size(neg);
damage=fix_size(damage);
%
figure(fig_num);
fig_num=fig_num+1;
plot(fn,pos,fn,neg);
out1=sprintf('Shock Response Spectrum  Q=%g',Q);
title(out1);
legend ('positive','negative',2);
xlabel('Natural Frequency (Hz)');
%
if(im==1)
    ylabel('Peak Accel (G)');
end    
%
if(im==2)
    if(iu==1)
        ylabel('Peak Pseudo Velocity (in/sec)');
    else
        ylabel('Peak Pseudo Velocity (cm/sec)');
    end
    maxY=max([max(pos) max(neg)]);
    minY=min([min(pos) min(neg)]);
%
    ymax=10^(ceil(log10(maxY)));
    ymin=10^(floor(log10(minY)));
%
    ylim([ymin ymax]);    
end
%
if(im==3)
    if(iu==1)
        ylabel('Peak Rel Disp (in)');
    else
        ylabel('Peak Rel Disp (mm)');
    end
end
%
grid on;
set(gca,'MinorGridLineStyle',':','GridLineStyle',':','XScale','log','YScale','log');
%
figure(fig_num);
fig_num=fig_num+1;
plot(fn,damage);
%
if(im==1)
       out1 = sprintf(' Acceleration Fatigue Damage Spectrum Q=%g b=%g',Q,bex);
       ylab=sprintf('Damage Index (G^{ %g })',bex);   
end
%
if(im==2)
       if(iu==1) 
            out1 = sprintf(' Pseudo Velocity Fatigue Damage Spectrum Q=%g b=%g',Q,bex);
            ylab=sprintf('Damage Index (ips^{ %g })',bex);             
       else
            out1 = sprintf(' Pseudo Velocity Fatigue Damage Spectrum Q=%g b=%g',Q,bex);           
            ylab=sprintf('Damage Index ((cm/sec)^{ %g })',bex);         
       end  
end
%
if(im==3)
       if(iu==1)  
            out1 = sprintf(' Relative Disp Fatigue Damage Spectrum Q=%g b=%g',Q,bex); 
            ylab=sprintf('Damage Index (in^{ %g })',bex);
       else
            out1 = sprintf(' Relative Disp Fatigue Damage Spectrum Q=%g b=%g',Q,bex); 
            ylab=sprintf('Damage Index (mm^{ %g })',bex);            
       end 
end
%
title(out1);
xlabel('Natural Frequency (Hz)');
ylabel(ylab);
grid on;
set(gca,'MinorGridLineStyle',':','GridLineStyle',':','XScale','log','YScale','log');
%
disp(' ');
%
b=sprintf('%g',bex);
b=strrep(b, '.', 'p');
%
if(im==1)  
    varname1=sprintf('accel_FDS_Q%g_b%s',Q,b);
end
if(im==2)
    varname1=sprintf('pv_FDS_Q%g_b%s',Q,b);
end
if(im==3)
    varname1=sprintf('rd_FDS_Q%g_b%s',Q,b);
end
%
out1=sprintf(' Output array: %s  -  fn(Hz) & Damage Index',varname1);
eval([varname1 ' = [fn damage];']);
disp(out1);
%
disp(' ');
disp(' The fatigue damage spectra is calculated from the amplitude (peak-valley)/2 ');
